package sun.print;

import java.util.Map;
import java.awt.RenderingHints;
import java.awt.Stroke;
import java.awt.Paint;
import java.awt.Composite;
import java.awt.font.GlyphVector;
import java.awt.image.BufferedImageOp;
import java.awt.geom.NoninvertibleTransformException;
import java.awt.image.renderable.RenderContext;
import java.awt.image.renderable.RenderableImage;
import java.awt.geom.AffineTransform;
import java.awt.image.RenderedImage;
import java.awt.image.BufferedImage;
import java.awt.image.ImageObserver;
import java.awt.Image;
import java.text.AttributedCharacterIterator;
import java.awt.Shape;
import java.awt.Rectangle;
import java.awt.font.FontRenderContext;
import java.awt.FontMetrics;
import java.awt.Font;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.GraphicsConfiguration;
import java.awt.print.PrinterJob;
import java.awt.print.PrinterGraphics;
import java.awt.Graphics2D;

public class ProxyGraphics2D extends Graphics2D implements PrinterGraphics
{
    Graphics2D mGraphics;
    PrinterJob mPrinterJob;
    
    public ProxyGraphics2D(Graphics2D mGraphics, PrinterJob mPrinterJob) {
        this.mGraphics = mGraphics;
        this.mPrinterJob = mPrinterJob;
    }
    
    public Graphics2D getDelegate() {
        return this.mGraphics;
    }
    
    public void setDelegate(Graphics2D mGraphics) {
        this.mGraphics = mGraphics;
    }
    
    @Override
    public PrinterJob getPrinterJob() {
        return this.mPrinterJob;
    }
    
    @Override
    public GraphicsConfiguration getDeviceConfiguration() {
        return ((RasterPrinterJob)this.mPrinterJob).getPrinterGraphicsConfig();
    }
    
    @Override
    public Graphics create() {
        return new ProxyGraphics2D((Graphics2D)this.mGraphics.create(), this.mPrinterJob);
    }
    
    @Override
    public void translate(int n, int n2) {
        this.mGraphics.translate(n, n2);
    }
    
    @Override
    public void translate(double n, double n2) {
        this.mGraphics.translate(n, n2);
    }
    
    @Override
    public void rotate(double n) {
        this.mGraphics.rotate(n);
    }
    
    @Override
    public void rotate(double n, double n2, double n3) {
        this.mGraphics.rotate(n, n2, n3);
    }
    
    @Override
    public void scale(double n, double n2) {
        this.mGraphics.scale(n, n2);
    }
    
    @Override
    public void shear(double n, double n2) {
        this.mGraphics.shear(n, n2);
    }
    
    @Override
    public Color getColor() {
        return this.mGraphics.getColor();
    }
    
    @Override
    public void setColor(Color color) {
        this.mGraphics.setColor(color);
    }
    
    @Override
    public void setPaintMode() {
        this.mGraphics.setPaintMode();
    }
    
    @Override
    public void setXORMode(Color xorMode) {
        this.mGraphics.setXORMode(xorMode);
    }
    
    @Override
    public Font getFont() {
        return this.mGraphics.getFont();
    }
    
    @Override
    public void setFont(Font font) {
        this.mGraphics.setFont(font);
    }
    
    @Override
    public FontMetrics getFontMetrics(Font font) {
        return this.mGraphics.getFontMetrics(font);
    }
    
    @Override
    public FontRenderContext getFontRenderContext() {
        return this.mGraphics.getFontRenderContext();
    }
    
    @Override
    public Rectangle getClipBounds() {
        return this.mGraphics.getClipBounds();
    }
    
    @Override
    public void clipRect(int n, int n2, int n3, int n4) {
        this.mGraphics.clipRect(n, n2, n3, n4);
    }
    
    @Override
    public void setClip(int n, int n2, int n3, int n4) {
        this.mGraphics.setClip(n, n2, n3, n4);
    }
    
    @Override
    public Shape getClip() {
        return this.mGraphics.getClip();
    }
    
    @Override
    public void setClip(Shape clip) {
        this.mGraphics.setClip(clip);
    }
    
    @Override
    public void copyArea(int n, int n2, int n3, int n4, int n5, int n6) {
        this.mGraphics.copyArea(n, n2, n3, n4, n5, n6);
    }
    
    @Override
    public void drawLine(int n, int n2, int n3, int n4) {
        this.mGraphics.drawLine(n, n2, n3, n4);
    }
    
    @Override
    public void fillRect(int n, int n2, int n3, int n4) {
        this.mGraphics.fillRect(n, n2, n3, n4);
    }
    
    @Override
    public void clearRect(int n, int n2, int n3, int n4) {
        this.mGraphics.clearRect(n, n2, n3, n4);
    }
    
    @Override
    public void drawRoundRect(int n, int n2, int n3, int n4, int n5, int n6) {
        this.mGraphics.drawRoundRect(n, n2, n3, n4, n5, n6);
    }
    
    @Override
    public void fillRoundRect(int n, int n2, int n3, int n4, int n5, int n6) {
        this.mGraphics.fillRoundRect(n, n2, n3, n4, n5, n6);
    }
    
    @Override
    public void drawOval(int n, int n2, int n3, int n4) {
        this.mGraphics.drawOval(n, n2, n3, n4);
    }
    
    @Override
    public void fillOval(int n, int n2, int n3, int n4) {
        this.mGraphics.fillOval(n, n2, n3, n4);
    }
    
    @Override
    public void drawArc(int n, int n2, int n3, int n4, int n5, int n6) {
        this.mGraphics.drawArc(n, n2, n3, n4, n5, n6);
    }
    
    @Override
    public void fillArc(int n, int n2, int n3, int n4, int n5, int n6) {
        this.mGraphics.fillArc(n, n2, n3, n4, n5, n6);
    }
    
    @Override
    public void drawPolyline(int[] array, int[] array2, int n) {
        this.mGraphics.drawPolyline(array, array2, n);
    }
    
    @Override
    public void drawPolygon(int[] array, int[] array2, int n) {
        this.mGraphics.drawPolygon(array, array2, n);
    }
    
    @Override
    public void fillPolygon(int[] array, int[] array2, int n) {
        this.mGraphics.fillPolygon(array, array2, n);
    }
    
    @Override
    public void drawString(String s, int n, int n2) {
        this.mGraphics.drawString(s, n, n2);
    }
    
    @Override
    public void drawString(AttributedCharacterIterator attributedCharacterIterator, int n, int n2) {
        this.mGraphics.drawString(attributedCharacterIterator, n, n2);
    }
    
    @Override
    public void drawString(AttributedCharacterIterator attributedCharacterIterator, float n, float n2) {
        this.mGraphics.drawString(attributedCharacterIterator, n, n2);
    }
    
    @Override
    public boolean drawImage(Image image, int n, int n2, ImageObserver imageObserver) {
        return this.mGraphics.drawImage(image, n, n2, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image image, int n, int n2, int n3, int n4, ImageObserver imageObserver) {
        return this.mGraphics.drawImage(image, n, n2, n3, n4, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image image, int n, int n2, Color color, ImageObserver imageObserver) {
        if (image == null) {
            return true;
        }
        int n3;
        if (this.needToCopyBgColorImage(image)) {
            n3 = this.mGraphics.drawImage(this.getBufferedImageCopy(image, color), n, n2, null);
        }
        else {
            n3 = this.mGraphics.drawImage(image, n, n2, color, imageObserver);
        }
        return n3;
    }
    
    @Override
    public boolean drawImage(Image image, int n, int n2, int n3, int n4, Color color, ImageObserver imageObserver) {
        if (image == null) {
            return true;
        }
        int n5;
        if (this.needToCopyBgColorImage(image)) {
            n5 = this.mGraphics.drawImage(this.getBufferedImageCopy(image, color), n, n2, n3, n4, null);
        }
        else {
            n5 = this.mGraphics.drawImage(image, n, n2, n3, n4, color, imageObserver);
        }
        return n5;
    }
    
    @Override
    public boolean drawImage(Image image, int n, int n2, int n3, int n4, int n5, int n6, int n7, int n8, ImageObserver imageObserver) {
        return this.mGraphics.drawImage(image, n, n2, n3, n4, n5, n6, n7, n8, imageObserver);
    }
    
    @Override
    public boolean drawImage(Image image, int n, int n2, int n3, int n4, int n5, int n6, int n7, int n8, Color color, ImageObserver imageObserver) {
        if (image == null) {
            return true;
        }
        int n9;
        if (this.needToCopyBgColorImage(image)) {
            n9 = this.mGraphics.drawImage(this.getBufferedImageCopy(image, color), n, n2, n3, n4, n6, n6, n7, n8, null);
        }
        else {
            n9 = this.mGraphics.drawImage(image, n, n2, n3, n4, n6, n6, n7, n8, color, imageObserver);
        }
        return n9;
    }
    
    private boolean needToCopyBgColorImage(Image image) {
        return (this.getTransform().getType() & 0x30) != 0x0;
    }
    
    private BufferedImage getBufferedImageCopy(Image image, Color color) {
        int width = image.getWidth(null);
        int height = image.getHeight(null);
        if (width > 0 && height > 0) {
            int type;
            if ((image instanceof BufferedImage)) {
                type = ((BufferedImage)image).getType();
            }
            else {
                type = 2;
            }
            BufferedImage o = new BufferedImage(width, height, type);
            Graphics2D graphics = o.createGraphics();
            graphics.drawImage(image, 0, 0, color, null);
            graphics.dispose();
            return o;
        }
        else {
            return null;
        }
    }
    
    @Override
    public void drawRenderedImage(RenderedImage renderedImage, AffineTransform affineTransform) {
        this.mGraphics.drawRenderedImage(renderedImage, affineTransform);
    }
    
    @Override
    public void drawRenderableImage(RenderableImage renderableImage, AffineTransform tx) {
        if (renderableImage == null) {
            return;
        }
        AffineTransform transform = this.getTransform();
        AffineTransform usr2dev = new AffineTransform(tx);
        usr2dev.concatenate(transform);
        RenderContext renderContext = new RenderContext(usr2dev);
        AffineTransform inverse;
        try {
            inverse = transform.createInverse();
        }
        catch (NoninvertibleTransformException ex) {
            renderContext = new RenderContext(transform);
            inverse = new AffineTransform();
        }
        this.drawRenderedImage(renderableImage.createRendering(renderContext), inverse);
        return;
    }
    
    @Override
    public void dispose() {
        this.mGraphics.dispose();
    }
    
    @Override
    public void finalize() {
    }
    
    @Override
    public void draw(Shape shape) {
        this.mGraphics.draw(shape);
    }
    
    @Override
    public boolean drawImage(Image image, AffineTransform affineTransform, ImageObserver imageObserver) {
        return this.mGraphics.drawImage(image, affineTransform, imageObserver);
    }
    
    @Override
    public void drawImage(BufferedImage bufferedImage, BufferedImageOp bufferedImageOp, int n, int n2) {
        this.mGraphics.drawImage(bufferedImage, bufferedImageOp, n, n2);
    }
    
    @Override
    public void drawString(String s, float n, float n2) {
        this.mGraphics.drawString(s, n, n2);
    }
    
    @Override
    public void drawGlyphVector(GlyphVector glyphVector, float n, float n2) {
        this.mGraphics.drawGlyphVector(glyphVector, n, n2);
    }
    
    @Override
    public void fill(Shape shape) {
        this.mGraphics.fill(shape);
    }
    
    @Override
    public boolean hit(Rectangle rectangle, Shape shape, boolean b) {
        return this.mGraphics.hit(rectangle, shape, b);
    }
    
    @Override
    public void setComposite(Composite composite) {
        this.mGraphics.setComposite(composite);
    }
    
    @Override
    public void setPaint(Paint paint) {
        this.mGraphics.setPaint(paint);
    }
    
    @Override
    public void setStroke(Stroke stroke) {
        this.mGraphics.setStroke(stroke);
    }
    
    @Override
    public void setRenderingHint(RenderingHints.Key key, Object o) {
        this.mGraphics.setRenderingHint(key, o);
    }
    
    @Override
    public Object getRenderingHint(RenderingHints.Key key) {
        return this.mGraphics.getRenderingHint(key);
    }
    
    @Override
    public void setRenderingHints(Map<?, ?> renderingHints) {
        this.mGraphics.setRenderingHints(renderingHints);
    }
    
    @Override
    public void addRenderingHints(Map<?, ?> map) {
        this.mGraphics.addRenderingHints(map);
    }
    
    @Override
    public RenderingHints getRenderingHints() {
        return this.mGraphics.getRenderingHints();
    }
    
    @Override
    public void transform(AffineTransform affineTransform) {
        this.mGraphics.transform(affineTransform);
    }
    
    @Override
    public void setTransform(AffineTransform transform) {
        this.mGraphics.setTransform(transform);
    }
    
    @Override
    public AffineTransform getTransform() {
        return this.mGraphics.getTransform();
    }
    
    @Override
    public Paint getPaint() {
        return this.mGraphics.getPaint();
    }
    
    @Override
    public Composite getComposite() {
        return this.mGraphics.getComposite();
    }
    
    @Override
    public void setBackground(Color background) {
        this.mGraphics.setBackground(background);
    }
    
    @Override
    public Color getBackground() {
        return this.mGraphics.getBackground();
    }
    
    @Override
    public Stroke getStroke() {
        return this.mGraphics.getStroke();
    }
    
    @Override
    public void clip(Shape shape) {
        this.mGraphics.clip(shape);
    }
}
